# Just: _Card Game_

Just a Card Game that build from Python. The main propose is playing with
websocket server that able to play some game together with any connected servers.

## Features

## Pocker

* https://github.com/annaymj/Python-Code/blob/master/Poker.py

## License

This project was licensed under the terms of the [MIT license](LICENSE), and thanks
all for reference public blogs that sharing knowledge to me.
